print.adm = function(x, ...){
  
  #'
  #' @export
  #' @noRd

  cat("age-depth model")
  return(invisible())
}